# This file was automatically generated by SWIG (http://www.swig.org).
# Version 2.0.10
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.



from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_example', [dirname(__file__)])
        except ImportError:
            import _example
            return _example
        if fp is not None:
            try:
                _mod = imp.load_module('_example', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _example = swig_import_helper()
    del swig_import_helper
else:
    import _example
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


class thang_data(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, thang_data, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, thang_data, name)
    __repr__ = _swig_repr
    __swig_setmethods__["x"] = _example.thang_data_x_set
    __swig_getmethods__["x"] = _example.thang_data_x_get
    if _newclass:x = _swig_property(_example.thang_data_x_get, _example.thang_data_x_set)
    __swig_setmethods__["y"] = _example.thang_data_y_set
    __swig_getmethods__["y"] = _example.thang_data_y_get
    if _newclass:y = _swig_property(_example.thang_data_y_get, _example.thang_data_y_set)
    def __init__(self): 
        this = _example.new_thang_data()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _example.delete_thang_data
    __del__ = lambda self : None;
thang_data_swigregister = _example.thang_data_swigregister
thang_data_swigregister(thang_data)

class thang(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, thang, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, thang, name)
    __repr__ = _swig_repr
    def __init__(self): 
        this = _example.new_thang()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _example.delete_thang
    __del__ = lambda self : None;
    def one(self) -> "int" : return _example.thang_one(self)
    def echo(self, *args) -> "std::string" : return _example.thang_echo(self, *args)
    def get_data(self) -> "thang_data" : return _example.thang_get_data(self)
thang_swigregister = _example.thang_swigregister
thang_swigregister(thang)


def factorial(*args) -> "int" :
  return _example.factorial(*args)
factorial = _example.factorial

def six() -> "int" :
  return _example.six()
six = _example.six
# This file is compatible with both classic and new-style classes.





from setuptools import setup, Extension
setup(
    name='pypithang',
    version='0.2',  # specified elsewhere
    packages=[''],
    package_dir={'': '.'},
#    include_package_data=True
   package_data={'': ['_example.so']},

)
